@@ -66,13 +66,13 @@ class Vm(object):
 
         # private class attributes
         self._statistics = {}  # Internal representation of statistics
-        self._vms = []         # Internal representation of each VMs 
+        self._vms = []         # Internal representation of each VMs
         self._vms_total = {}   # Total VMs statistics
 
     def connect(self):
         self.ssh.connect()
 
-    # Tracing wrapper on ssh 
+    # Tracing wrapper on ssh
     def trace_open(self, filename="tracefile.log"):
         self.ssh.trace_open(filename="tracefile.log")
 
@@ -243,7 +243,7 @@ class Vm(object):
 
     def _get_processes(self):
         """
-        Retrieve qemu processes from KVM server 
+        Retrieve qemu processes from KVM server
         Fills _vms and _vms_total attributs
 
         Workaround 200824 : it has been seen that sometimes the output buffer
@@ -289,13 +289,13 @@ class Vm(object):
 
                 if kvm_end:
                     log.debug("Full line seen")
-                    full_line = line 
+                    full_line = line
                     kvm_start = False
                     kvm_end = False
                     need_tokenize = True
 
                 else :
-                    log.warning("Start without end, line is split, first fragment seen")
+                    log.info("Start without end, line is split, first fragment seen")
                     full_line = line
 
             else:
@@ -317,13 +317,13 @@ class Vm(object):
                 self._vms.append(result)
 
                 # Record total for all VMs
-                if result['cpu']:
+                if 'cpu' in result:
                     # Count number of VMs based on the cpu token
-                    self._vms_total['number'] += 1 
+                    self._vms_total['number'] += 1
                     self._vms_total['cpu'] += int(result['cpu'])
                     log.debug("vms_total_cpu={}".format(self._vms_total['cpu']))
 
-                if result['memory']:
+                if 'memory' in result:
                     self._vms_total['memory'] += int(result['memory'])
                     log.debug("vms_total_memory={}".format(self._vms_total['memory']))
 
@@ -331,7 +331,9 @@ class Vm(object):
         """
         Tokenise ps lines has run into a dictionnary where the key is the option
         (the -xxxx). Only tokenize tokens we are interested in
-        
+
+        210316 : manually started vm need to be exculded (the id does not match
+        guest=\d+), seen on radon  
 
         return: dictionary like
         {
@@ -348,8 +350,9 @@ class Vm(object):
         memory = None
         template = None
 
-        # VM id
-        id_match = re.search("\sguest=(\d+)(?:,|\s)", line)
+        # VM id only digit if launched from labsetup
+        # other if launched manually from a user
+        id_match = re.search("\sguest=([A-Za-z0-9_\-\.\/\s]+)(?:,|\s)", line)
         if id_match:
             vm_id = id_match.groups(0)[0]
             log.debug("id={}".format(vm_id))
@@ -393,9 +396,10 @@ class Vm(object):
             return vm
 
         else:
-            log.warning("tokenize failed : line={}".format(line))
+            log.warning("tokenize failed (maybe a manually started VM) vm_id={} cpu={} memory={}".format(vm_id, cpu, memory))
 
-        return  
+        # Need to return an empty dictionnary
+        return {}
 
     def dump_statistics(self):
         """
